﻿using Newtonsoft.Json;
using System;
using System.IO;
using System.Linq;
using System.Reflection;

namespace AlphaTrust.CreateTransactions
{
    public static class Extensions
    {
        public static T DeserializeToObject<T>(this string jsonString) where T : class
        {
            try
            {
                return JsonConvert.DeserializeObject<T>(jsonString, new JsonSerializerSettings
                                                                    {
                                                                        DefaultValueHandling = DefaultValueHandling.Populate,
                                                                        NullValueHandling = NullValueHandling.Ignore
                                                                    });
            }
            catch
            {
                return default;
            }
        }

        public static string FormatElapsed(this TimeSpan timeSpan)
        {
            return $"{timeSpan.Minutes:00}:{timeSpan.Seconds:00}.{timeSpan.Milliseconds:000}";
        }

        public static byte[] ReadAllBytes(this Assembly assembly, string endsWith)
        {
            using (var resourceStream = assembly.GetResourceStream(endsWith))
            {
                if (resourceStream == null)
                {
                    return null;
                }

                using (var memory = new MemoryStream())
                {
                    resourceStream.CopyTo(memory);
                    return memory.ToArray();
                }
            }
        }

        private static Stream GetResourceStream(this Assembly assembly, string endsWith)
        {
            var resourceName = assembly.GetManifestResourceNames().Single(str => str.EndsWith(endsWith));
            var resourceStream = assembly.GetManifestResourceStream(resourceName);
            return resourceStream;
        }
    }
}